==> libunistring-0.9.7.tar.gz: libunistring-0.9.7/lib/unicase/u8-ct-totitle.c <==
/* Titlecase mapping for UTF-8 substrings (locale dependent).
   Copyright (C) 2009-2016 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2009.

   This program is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at your
       option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at your
       option) any later version.

   or both in parallel, as here.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unicase.h"

#include <errno.h>
#include <stdbool.h>
#include <stddef.h>
#include <stdlib.h>

#include "unistr.h"
#include "unictype.h"
#include "uniwbrk.h"
#include "uninorm.h"
#include "caseprop.h"
#include "context.h"
#include "special-casing.h"

#define FUNC u8_ct_totitle
#define UNIT uint8_t
#define U_WORDBREAKS u8_wordbreaks
#define U_MBTOUC_UNSAFE u8_mbtouc_unsafe
#define U_UCTOMB u8_uctomb
#define U_CPY u8_cpy
#define U_NORMALIZE u8_normalize
#include "u-ct-totitle.h"

==> libunistring-0.9.9.tar.gz: libunistring-0.9.9/lib/unicase/u8-ct-totitle.c <==
/* Titlecase mapping for UTF-8 substrings (locale dependent).
   Copyright (C) 2009-2018 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2009.

   This program is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at your
       option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at your
       option) any later version.

   or both in parallel, as here.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unicase.h"

#include <errno.h>
#include <stdbool.h>
#include <stddef.h>
#include <stdlib.h>

#include "unistr.h"
#include "unictype.h"
#include "uniwbrk.h"
#include "uninorm.h"
#include "caseprop.h"
#include "context.h"
#include "unicase/special-casing.h"

#define FUNC u8_ct_totitle
#define UNIT uint8_t
#define U_WORDBREAKS u8_wordbreaks
#define U_MBTOUC_UNSAFE u8_mbtouc_unsafe
#define U_UCTOMB u8_uctomb
#define U_CPY u8_cpy
#define U_NORMALIZE u8_normalize
#include "u-ct-totitle.h"
